AudioTrackParams

Struct AudioTrackParams 

pub struct AudioTrackParams<E: DemuxAdapter> { /* private fields */ }
Payload for TrackParams::Audio.

Implementations

Source

impl<E: DemuxAdapter> AudioTrackParams<E>

pub const fn new( codec: E::CodecId, sample_rate: u32, channel_count: u8, sample_format: <E::Audio as AudioAdapter>::SampleFormat, channel_layout: <E::Audio as AudioAdapter>::ChannelLayout, ) -> Self

Constructs an AudioTrackParams.

pub const fn codec(&self) -> E::CodecId

Returns the codec identifier.

pub const fn sample_rate(&self) -> u32

Returns the sample rate in Hz.

pub const fn channel_count(&self) -> u8

Returns the channel count.

pub const fn sample_format(&self) -> <E::Audio as AudioAdapter>::SampleFormat

Returns the sample format the track declares, in the backend’s vocabulary.

pub const fn channel_layout(&self) -> &<E::Audio as AudioAdapter>::ChannelLayout

Returns the channel layout the track declares, in the backend’s vocabulary.